@@ -1,13 +1,14 @@
 acf1 <-
 function(series, max.lag=NULL, plot=TRUE, main=NULL, ylim=NULL, pacf=FALSE, 
-          ylab=NULL, na.action = na.pass, ...){
+          ylab=NULL, xlab=NULL, na.action = na.pass, ...){
   frequency = stats::frequency
   acf       = stats::acf
   xfreq     = frequency(series)
   num       = length(series)
 
+  if (num < 3) stop("More than 2 observations are needed")
   if (num > 59 & is.null(max.lag))  max.lag = max(ceiling(10+sqrt(num)), 4*xfreq) 
-  if (num < 60 & is.null(max.lag))  max.lag = floor(5*log10(num+5))
+  if (num < 60 & is.null(max.lag))  max.lag = min(floor(6*log10(num+5)), num-2)
   if (max.lag > (num-1)) stop("Number of lags exceeds number of observations")
   if (is.null(main)) main = paste("Series: ",deparse(substitute(series)))
 
@@ -34,6 +35,7 @@ function(series, max.lag=NULL, plot=TRUE, main=NULL, ylim=NULL, pacf=FALSE,
   Xlab = ifelse(xfreq>1, paste('LAG \u00F7', xfreq), 'LAG')
   Ylab = ifelse(pacf, 'PACF', 'ACF')  
   if (!is.null(ylab)) Ylab=ylab
+  if (!is.null(xlab)) Xlab=xlab
   tsplot(LAG, ACF, ylim=ylim, main=main, xlab=Xlab, ylab=Ylab, type='h', ...)
   abline(h=c(0,L,U), lty=c(1,2,2), col=c(8,4,4))
   return(round(ACF, 2)) 
