@@ -2,7 +2,8 @@ tsplot <- function(x, y = NULL, main=NULL, ylab=NULL, xlab='Time', type=NULL,
                     margins=.25, ncolm=1, byrow=TRUE, nx = NULL, ny = nx, 
                     minor=TRUE, nxm=2, nym=1, xm.grid=TRUE, ym.grid=TRUE, col=1, 
                     gg=FALSE, spaghetti=FALSE, pch=NULL, lty=1, lwd=1, mgpp=0, 
-                    topper=NULL, ...)
+                    topper=NULL, addLegend=FALSE, location='topright', boxit=TRUE,
+                    horiz=FALSE, legend=NULL, llwd=NULL, scale=1, ...)
 {
   nser   = max(NCOL(x), NCOL(y))
   if (is.null(topper)){
@@ -35,8 +36,9 @@ tsplot <- function(x, y = NULL, main=NULL, ylab=NULL, xlab='Time', type=NULL,
    if(byrow){
    par(mfrow = c(prow, ncolm),  cex.lab=1.1, oma = c(0,0,3*topper,0))
    } else {
-   par(mfcol = c(prow, ncolm), cex.lab=1.1, oma = c(0,0,3*topper,0))
+   par(mfcol = c(prow, ncolm), cex.lab=1.1, oma = c(0,0,3*topper,0) )
    }
+par(cex=.9*scale)
    if (is.null(y) & is.null(ylab) ) { ylab=colnames(as.matrix(x))}
    if (!is.null(y) & is.null(ylab) )  { ylab=colnames(as.matrix(y))} 
    for (h in 1:nser) {
@@ -69,11 +71,12 @@ tsplot <- function(x, y = NULL, main=NULL, ylab=NULL, xlab='Time', type=NULL,
    culer = rep(col, nser)
    if(byrow){
    par(mfrow = c(prow, ncolm), cex.lab=1.1, oma = c(0,.25,3*topper,0)+margins, tcl=-.2, 
-         cex.axis=.9)
+         cex.axis=.9, cex=.9*scale)
    } else {
    par(mfcol = c(prow, ncolm), cex.lab=1.1, oma = c(0,.25,3*topper,0)+margins, tcl=-.2, 
-         cex.axis=.9)
+         cex.axis=.9, cex=.9*scale)
    }
+par(cex=.9*scale)
    if (is.null(y) & is.null(ylab) ) { ylab=colnames(as.matrix(x))}
    if (!is.null(y) & is.null(ylab) )  { ylab=colnames(as.matrix(y))} 
    for (h in 1:nser) {
@@ -105,6 +108,21 @@ tsplot <- function(x, y = NULL, main=NULL, ylab=NULL, xlab='Time', type=NULL,
    for (h in 1:nser) { lines(x, y[,h], col=culer[h], type=type1, pch=pch[h], 
                           lty=lty[h], lwd=lwd[h], ...) }
    }
+  if (addLegend){ 
+    if (is.null(legend)){
+      if (is.null(y)){ namez = colnames(as.matrix(x))
+       } else { namez = colnames(as.matrix(y))
+      }
+     } else {
+      namez = legend
+     }
+   if (gg) { box.col=gray(1,.7); bg=gray(.92,.8) } else { box.col=gray(.62,.3); bg=gray(1,.8) }
+   if (boxit) bty='o' else bty='n'
+   if (!is.null(llwd)) lwd=llwd 
+   legend(location, legend=namez, lty=lty, col=col, bty=bty, box.col=box.col, bg=bg,
+          lwd=lwd, pch=pch, horiz=horiz, cex=.9) 
+  }
+    if (gg) { box(col=gray(1)) } else { box(col=gray(.62)) }
 }
 return(invisible(grDevices::recordPlot()))
 }
